"use strict";
var cDispo = require("content-disposition");
var cType = require("content-type");
var funkster_http_1 = require("funkster-http");
;
;
function parse(name, transform, headers) {
    var value = headers[name];
    return value ? transform(value) : null;
}
function parseContentType(headers) {
    return parse('content-type', function (x) {
        var parsedType = cType.parse(x);
        return {
            mediaType: parsedType.type,
            parameters: parsedType.parameters
        };
    }, headers);
}
function parseContentLength(headers) {
    return parse('content-length', function (x) { return parseInt(x, 10); }, headers);
}
function parseContentLanguage(headers) {
    return parse('content-language', function (x) { return x; }, headers);
}
function parseContentEncoding(headers) {
    return parse('content-encoding', function (x) { return x; }, headers);
}
function parseContentLocation(headers) {
    return parse('content-location', function (x) { return x; }, headers);
}
function parseContentDisposition(headers) {
    return parse('content-disposition', cDispo.parse, headers);
}
function parseContentHeaders(handler) {
    return funkster_http_1.request(function (req) {
        var contentType = parseContentType(req.headers);
        var contentLength = parseContentLength(req.headers);
        var contentLanguage = parseContentLanguage(req.headers);
        var contentEncoding = parseContentEncoding(req.headers);
        var contentLocation = parseContentLocation(req.headers);
        var contentDisposition = parseContentDisposition(req.headers);
        var parsedHeaders = {
            disposition: contentDisposition,
            encoding: contentEncoding,
            language: contentLanguage,
            length: contentLength,
            location: contentLocation,
            type: contentType
        };
        return handler(parsedHeaders);
    });
}
exports.parseContentHeaders = parseContentHeaders;
function setContentType(type) {
    if (typeof type === 'string') {
        return funkster_http_1.setHeader('Content-Type', type);
    }
    else {
        var convertedContentType = {
            parameters: type.parameters,
            type: type.mediaType
        };
        return funkster_http_1.setHeader('Content-Type', cType.format(convertedContentType));
    }
}
exports.setContentType = setContentType;
function setContentDisposition(filenameOrOptions, options) {
    if (!filenameOrOptions) {
        return funkster_http_1.setHeader('Content-Disposition', cDispo());
    }
    else if (typeof filenameOrOptions === 'string') {
        return funkster_http_1.setHeader('Content-Disposition', cDispo(filenameOrOptions, options));
    }
    else {
        return funkster_http_1.setHeader('Content-Disposition', cDispo(undefined, filenameOrOptions));
    }
}
exports.setContentDisposition = setContentDisposition;
function setContentLength(length) {
    return funkster_http_1.setHeader('Content-Length', String(length));
}
exports.setContentLength = setContentLength;
function setContentLanguage(language) {
    return funkster_http_1.setHeader('Content-Language', language);
}
exports.setContentLanguage = setContentLanguage;
function setContentEncoding(encoding) {
    return funkster_http_1.setHeader('Content-Encoding', encoding);
}
exports.setContentEncoding = setContentEncoding;
function setContentLocation(location) {
    return funkster_http_1.setHeader('Content-Location', location);
}
exports.setContentLocation = setContentLocation;
